@@ -287,6 +287,8 @@ class DbDirectives {
 
 
 window.addEventListener('load',function(){
+    if (typeof languagePluginLoader === 'undefined')
+        return 
     languagePluginLoader.then(() => 
     pyodide.runPythonAsync(`
         import js
